scipy.spatial.cKDTree
=====================

.. currentmodule:: scipy.spatial

.. autoclass:: cKDTree

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         cKDTree.query



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         cKDTree.data
         cKDTree.leafsize
         cKDTree.m
         cKDTree.maxes
         cKDTree.mins
         cKDTree.n

